@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2017, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -23,6 +23,4 @@ package org.ejml.data;
  *
  * @author Peter Abeles
  */
-public abstract class DMatrix1Row extends DMatrixD1 {
-
-}
+public abstract class DMatrix1Row extends DMatrixD1 {}
