@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2017, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2009-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -19,7 +19,7 @@
 package org.ejml.dense.fixed;
 
 import org.ejml.dense.row.MatrixFeatures_DDRM;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author Peter Abeles
@@ -27,7 +27,7 @@ import org.junit.Test;
 // TODO this should be improved by creating custom matrices for many of these functions.
 public abstract class CompareFixedToMatrixFeatures_DDRM extends CompareFixed_DDRM {
 
-    public CompareFixedToMatrixFeatures_DDRM(Class classFixed) {
+    protected CompareFixedToMatrixFeatures_DDRM(Class classFixed) {
         super(classFixed, MatrixFeatures_DDRM.class);
     }
 
