@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2017, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2009-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -19,14 +19,14 @@
 package org.ejml.dense.fixed;
 
 import org.ejml.dense.row.NormOps_DDRM;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author Peter Abeles
  */
 public abstract class CompareFixedToNormOps_DDRM extends CompareFixed_DDRM {
 
-    public CompareFixedToNormOps_DDRM(Class classFixed) {
+    protected CompareFixedToNormOps_DDRM(Class classFixed) {
         super(classFixed, NormOps_DDRM.class);
     }
 
