@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2017, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2009-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -20,7 +20,7 @@ package org.ejml.dense.row.decomposition.eig;
 
 import org.ejml.UtilEjml;
 import org.ejml.interfaces.decomposition.EigenDecomposition_F64;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 
 /**
@@ -33,6 +33,7 @@ public class TestSwitchingEigenDecomposition_DDRM extends GeneralEigenDecomposit
     }
 
     @Test
+    @Override
     public void allTests() {
         super.allTests();
 //        super.justEigenValues();
