@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2018, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -26,14 +26,14 @@ import org.ejml.data.DMatrixSparseCSC;
 import org.ejml.data.IGrowArray;
 import org.ejml.dense.row.MatrixFeatures_DDRM;
 import org.ejml.dense.row.RandomMatrices_DDRM;
-import org.ejml.ops.ConvertDMatrixStruct;
+import org.ejml.ops.DConvertMatrixStruct;
 import org.ejml.sparse.csc.CommonOps_DSCC;
 import org.ejml.sparse.csc.RandomMatrices_DSCC;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.util.Random;
 
-import static org.junit.Assert.*;
+import static org.junit.jupiter.api.Assertions.*;
 
 /**
  * @author Peter Abeles
@@ -102,33 +102,46 @@ public class TestTriangularSolver_DSCC {
     }
 
     public void solve_sparseX_vector( boolean lower ) {
-        int m = 5;
-        int w[] = new int[m*2];
-
         for (int trial = 0; trial < 10; trial++) {
-            for (int nz_size : new int[]{5, 8, 10, 20}) {
-                int lengthX = rand.nextInt(3)+3;
+            for( int m : new int[]{1,2,5,10,20,50}) {
+                int[] w = new int[m*2];
+                int maxSize = m*m;
+                int nz_size_G = m;
+                while( nz_size_G < maxSize ) {
+                    DMatrixSparseCSC G = createTriangular(lower,m, nz_size_G);
 
-                DMatrixSparseCSC G;
-                if( lower)
-                    G = RandomMatrices_DSCC.triangleLower(m, 0, nz_size, -1, 1, rand);
-                else
-                    G = RandomMatrices_DSCC.triangleUpper(m, 0, nz_size, -1, 1, rand);
-                DMatrixSparseCSC b = RandomMatrices_DSCC.rectangle(m, 1,lengthX, rand);
-                DMatrixRMaj x = new DMatrixRMaj(b.numRows,b.numCols);
+                    int lengthX = rand.nextInt(m/2+1)+m/2;
+                    DMatrixSparseCSC b = RandomMatrices_DSCC.rectangle(m, 1,lengthX, rand);
+                    DMatrixRMaj x = new DMatrixRMaj(b.numRows,b.numCols);
 
-                int ret = TriangularSolver_DSCC.solveColB(G,lower, b,0, x.data,null, null, w);
-                assertTrue(m-lengthX >= ret);
+                    int ret = TriangularSolver_DSCC.solveColB(G,lower, b,0, x.data,null, null, w);
+                    assertTrue(m-lengthX >= ret);
 
-                DMatrixRMaj found = x.createLike();
-                CommonOps_DSCC.mult(G, x, found);
+                    DMatrixRMaj found = x.createLike();
+                    CommonOps_DSCC.mult(G, x, found);
 
-                DMatrixRMaj expected = ConvertDMatrixStruct.convert(b,(DMatrixRMaj)null);
-                assertTrue(MatrixFeatures_DDRM.isEquals(found, expected, UtilEjml.TEST_F64));
+                    DMatrixRMaj expected = DConvertMatrixStruct.convert(b,(DMatrixRMaj)null);
+                    assertTrue(MatrixFeatures_DDRM.isEquals(found, expected, UtilEjml.TEST_F64));
+                    nz_size_G = (int)(nz_size_G*1.5);
+                }
             }
         }
     }
 
+    private DMatrixSparseCSC createTriangular( boolean lower , int rows , int nz_size ) {
+        DMatrixSparseCSC T;
+        if( lower)
+            T = RandomMatrices_DSCC.triangleLower(rows, 0, nz_size, -1, 1, rand);
+        else
+            T = RandomMatrices_DSCC.triangleUpper(rows, 0, nz_size, -1, 1, rand);
+
+        // make sure the diagonal elements are close to one so that the system is stable
+        for (int row = 0; row < rows; row++) {
+            T.set(row,row, 1.0 + (double) (rand.nextGaussian() * 0.001) );
+        }
+        return T;
+    }
+
     @Test
     public void solve_sparseX_matrix_square() {
         // test square matrix
@@ -145,11 +158,7 @@ public class TestTriangularSolver_DSCC {
             for (int nz_size : new int[]{5, 8, 10, 20}) {
                 int lengthX = rand.nextInt(3)+3;
 
-                DMatrixSparseCSC G;
-                if( lower)
-                    G = RandomMatrices_DSCC.triangleLower(5, 0, nz_size, -1, 1, rand);
-                else
-                    G = RandomMatrices_DSCC.triangleUpper(5, 0, nz_size, -1, 1, rand);
+                DMatrixSparseCSC G = createTriangular(lower,5, nz_size);
                 DMatrixSparseCSC b = RandomMatrices_DSCC.rectangle(5, 2,lengthX*2, rand);
                 DMatrixSparseCSC x = new DMatrixSparseCSC(b.numRows,b.numCols,1);
 
@@ -164,8 +173,8 @@ public class TestTriangularSolver_DSCC {
 
                 //===========================================================
                 // now try it with pivots
-                int p[] = UtilEjml.shuffled(G.numRows,rand);
-                int pinv[] = CommonOps_DSCC.permutationInverse(p,p.length);
+                int[] p = UtilEjml.shuffled(G.numRows,rand);
+                int[] pinv = CommonOps_DSCC.permutationInverse(p,p.length);
 
                 DMatrixSparseCSC Gp = G.createLike();
                 CommonOps_DSCC.permute(null,G,p,Gp);
@@ -198,11 +207,7 @@ public class TestTriangularSolver_DSCC {
 
                 int B_nz_count = (int)(N*Bcol*(rand.nextDouble()*0.7+0.35)); // bias so it will fill up
 
-                DMatrixSparseCSC G;
-                if( lower)
-                    G = RandomMatrices_DSCC.triangleLower(N, 0, nz_size, -1, 1, rand);
-                else
-                    G = RandomMatrices_DSCC.triangleUpper(N, 0, nz_size, -1, 1, rand);
+                DMatrixSparseCSC G = createTriangular(lower,N, nz_size);
                 DMatrixSparseCSC b = RandomMatrices_DSCC.rectangle(N, Bcol,B_nz_count, rand);
                 DMatrixSparseCSC x = new DMatrixSparseCSC(b.numRows,b.numCols,1);
 
@@ -220,8 +225,8 @@ public class TestTriangularSolver_DSCC {
 
                 //===========================================================
                 // now try it with pivots
-                int p[] = UtilEjml.shuffled(G.numRows,rand);
-                int pinv[] = CommonOps_DSCC.permutationInverse(p,p.length);
+                int[] p = UtilEjml.shuffled(G.numRows,rand);
+                int[] pinv = CommonOps_DSCC.permutationInverse(p,p.length);
 
                 DMatrixSparseCSC Gp = G.createLike();
                 CommonOps_DSCC.permute(null,G,p,Gp);
@@ -306,8 +311,8 @@ public class TestTriangularSolver_DSCC {
 
         //======================================================================
         // now try it with pivots
-        int p[] = UtilEjml.shuffled(R.numRows,rand);
-        int pinv[] = CommonOps_DSCC.permutationInverse(p,p.length);
+        int[] p = UtilEjml.shuffled(R.numRows,rand);
+        int[] pinv = CommonOps_DSCC.permutationInverse(p,p.length);
 
         DMatrixSparseCSC Gp = G.createLike();
         CommonOps_DSCC.permute(null,G,p,Gp);
@@ -326,21 +331,17 @@ public class TestTriangularSolver_DSCC {
 
     public void solveColB_pivots_sparseX_vector( boolean lower ) {
         int m = 5;
-        int w[] = new int[m*2];
+        int[] w = new int[m*2];
 
         for (int trial = 0; trial < 10; trial++) {
             for (int nz_size : new int[]{5, 8, 10, 20}) {
 
-                int p[] = UtilEjml.shuffled(m,rand);
-                int pinv[] = CommonOps_DSCC.permutationInverse(p,5);
+                int[] p = UtilEjml.shuffled(m,rand);
+                int[] pinv = CommonOps_DSCC.permutationInverse(p,5);
 
                 int lengthX = rand.nextInt(3)+3;
 
-                DMatrixSparseCSC G;
-                if( lower)
-                    G = RandomMatrices_DSCC.triangleLower(m, 0, nz_size, -1, 1, rand);
-                else
-                    G = RandomMatrices_DSCC.triangleUpper(m, 0, nz_size, -1, 1, rand);
+                DMatrixSparseCSC G = createTriangular(lower,m, nz_size);
 
                 DMatrixSparseCSC Gp = new DMatrixSparseCSC(m,5,0);
                 CommonOps_DSCC.permute(null,G,p,Gp);
@@ -354,7 +355,7 @@ public class TestTriangularSolver_DSCC {
                 DMatrixRMaj found = x.createLike();
                 CommonOps_DSCC.mult(G, x, found);
 
-                DMatrixRMaj expected = ConvertDMatrixStruct.convert(b,(DMatrixRMaj)null);
+                DMatrixRMaj expected = DConvertMatrixStruct.convert(b,(DMatrixRMaj)null);
                 assertTrue(MatrixFeatures_DDRM.isEquals(found, expected, UtilEjml.TEST_F64));
             }
         }
@@ -369,8 +370,8 @@ public class TestTriangularSolver_DSCC {
         DMatrixSparseCSC A = CommonOps_DSCC.diag(1,2,3);
         DMatrixSparseCSC B = RandomMatrices_DSCC.rectangle(3,1,3,-1,1,rand);
 
-        int xi[] = new int[A.numCols];
-        int w[] = new int[B.numRows*2];
+        int[] xi = new int[A.numCols];
+        int[] w = new int[B.numRows*2];
 
         // A is diagonal and B is filled in
         int top = TriangularSolver_DSCC.searchNzRowsInX(A,B,0,null,xi,w);
@@ -416,8 +417,8 @@ public class TestTriangularSolver_DSCC {
         DMatrixSparseCSC A = RandomMatrices_DSCC.triangleLower(4,0,16, -1,1,rand);
         DMatrixSparseCSC B = RandomMatrices_DSCC.rectangle(4,1,4,-1,1,rand);
 
-        int xi[] = new int[A.numCols];
-        int w[] = new int[A.numCols*2];
+        int[] xi = new int[A.numCols];
+        int[] w = new int[A.numCols*2];
 
         int top = TriangularSolver_DSCC.searchNzRowsInX(A,B,0,null,xi,w);
         assertEquals(0,top);
@@ -463,12 +464,12 @@ public class TestTriangularSolver_DSCC {
                         "1 0 0 1 0 " +
                         "0 1 0 0 1",5);
 
-        DMatrixSparseCSC A = ConvertDMatrixStruct.convert(D,(DMatrixSparseCSC)null, UtilEjml.EPS);
+        DMatrixSparseCSC A = DConvertMatrixStruct.convert(D,(DMatrixSparseCSC)null, UtilEjml.EPS);
 
         DMatrixSparseCSC B = RandomMatrices_DSCC.rectangle(5,1,5,-1,1,rand);
 
-        int xi[] = new int[A.numCols];
-        int w[] = new int[B.numRows*2];
+        int[] xi = new int[A.numCols];
+        int[] w = new int[B.numRows*2];
 
         int top = TriangularSolver_DSCC.searchNzRowsInX(A,B,0,null,xi,w);
         assertEquals(0,top);
@@ -488,8 +489,8 @@ public class TestTriangularSolver_DSCC {
             DMatrixSparseCSC A = RandomMatrices_DSCC.triangleLower(5,0,5,-1,1,rand);
             DMatrixSparseCSC B = RandomMatrices_DSCC.rectangle(5,2,2,-1,1,rand);
 
-            int xi[] = new int[A.numCols];
-            int w[] = new int[A.numCols*2];
+            int[] xi = new int[A.numCols];
+            int[] w = new int[A.numCols*2];
 
             int top = TriangularSolver_DSCC.searchNzRowsInX(A,B,0,null,xi,w);
             for (int j = 0; j < A.numCols; j++) {
@@ -499,8 +500,8 @@ public class TestTriangularSolver_DSCC {
             DMatrixSparseCSC bottom = RandomMatrices_DSCC.rectangle(4,5,10,-1,1,rand);
             A = CommonOps_DSCC.concatRows(A,bottom,null);
 
-            int xi2[] = new int[A.numCols];
-            int w2[] = new int[A.numCols*2];
+            int[] xi2 = new int[A.numCols];
+            int[] w2 = new int[A.numCols*2];
 
             int top2 = TriangularSolver_DSCC.searchNzRowsInX(A,B,0,null,xi2,w2);
             for (int j = 0; j < A.numCols; j++) {
@@ -526,7 +527,7 @@ public class TestTriangularSolver_DSCC {
                         "0 0 0 1 1 " +
                         "0 0 0 0 1",5);
 
-        int parent[] = new int[A.numCols];
+        int[] parent = new int[A.numCols];
 
         TriangularSolver_DSCC.eliminationTree(A,false,parent,null);
 
@@ -548,7 +549,7 @@ public class TestTriangularSolver_DSCC {
                         "0 0 0 1 0 " +
                         "0 0 0 0 1",5);
 
-        int parent[] = new int[A.numCols];
+        int[] parent = new int[A.numCols];
 
         TriangularSolver_DSCC.eliminationTree(A,false,parent,null);
 
@@ -569,11 +570,11 @@ public class TestTriangularSolver_DSCC {
                         "0 0 0 1 0 " +
                         "0 0 0 0 1 ",5);
 
-        int parent[] = new int[A.numCols];
+        int[] parent = new int[A.numCols];
 
         TriangularSolver_DSCC.eliminationTree(A,false,parent,null);
 
-        int expected[] = new int[]{-1,2,3,4,-1};
+        int[] expected = new int[]{-1,2,3,4,-1};
 
         for (int i = 0; i < A.numCols; i++) {
             assertEquals(expected[i],parent[i]);
@@ -594,11 +595,11 @@ public class TestTriangularSolver_DSCC {
                         "0 0 0 0 0 1 1 " +
                         "0 0 0 0 0 0 1 ",7);
 
-        int parent[] = new int[A.numCols];
+        int[] parent = new int[A.numCols];
 
         TriangularSolver_DSCC.eliminationTree(A,false,parent,null);
 
-        int expected[] = new int[]{2,3,3,4,5,6,-1};
+        int[] expected = new int[]{2,3,3,4,5,6,-1};
 
         for (int i = 0; i < A.numCols; i++) {
             assertEquals(expected[i],parent[i]);
@@ -619,11 +620,11 @@ public class TestTriangularSolver_DSCC {
                         "0 0 0 0 1 0 " +
                         "0 0 0 0 0 1 " ,6);
 
-        int parent[] = new int[A.numCols];
+        int[] parent = new int[A.numCols];
 
         TriangularSolver_DSCC.eliminationTree(A,false,parent,null);
 
-        int expected[] = new int[]{2,3,3,4,5,-1};
+        int[] expected = new int[]{2,3,3,4,5,-1};
 
         for (int i = 0; i < A.numCols; i++) {
             assertEquals(expected[i],parent[i]);
@@ -643,7 +644,7 @@ public class TestTriangularSolver_DSCC {
             int nz = (int)(((N-1)*(N-1)/2)*(rand.nextDouble()*0.8+0.2))+N;
             DMatrixSparseCSC A = RandomMatrices_DSCC.triangleUpper(N,0,nz,-1,1,rand);
 
-            int parent[] = new int[A.numCols];
+            int[] parent = new int[A.numCols];
             TriangularSolver_DSCC.eliminationTree(A,false,parent,null);
 
             for (int col = 0; col < A.numCols; col++) {
@@ -654,18 +655,18 @@ public class TestTriangularSolver_DSCC {
                 for (int j = idx0; j < idx1-1; j++) {
                     int row = A.nz_rows[j];
 
-                    checkPathEliminationTree(row,col,parent,N);
+                    checkPathEliminationTree(row,col,parent);
                 }
             }
         }
     }
 
-    private void checkPathEliminationTree( int start , int end , int parent[], int N ) {
+    private void checkPathEliminationTree(int start , int end , int[] parent) {
         int i = start;
         while( i < end ) {
             i = parent[i];
         }
-        assertTrue(i==end);
+        assertEquals(end, i);
     }
 
     /**
@@ -679,12 +680,12 @@ public class TestTriangularSolver_DSCC {
 //            System.out.println("mc = "+mc+"   N = "+N);
 
             DMatrixSparseCSC A = RandomMatrices_DSCC.triangle(true,N,0.1,0.5,rand);
-            DMatrixSparseCSC ATA = new DMatrixSparseCSC(N,N,0);
-            CommonOps_DSCC.multTransA(A,A,ATA,null,null);
+            DMatrixSparseCSC At = CommonOps_DSCC.transpose(A,null,null);
+            DMatrixSparseCSC ATA = CommonOps_DSCC.mult(At,A,null,null,null);
 
-            int expected[] = new int[A.numCols];
+            int[] expected = new int[A.numCols];
             TriangularSolver_DSCC.eliminationTree(ATA,false,expected,null);
-            int found[] = new int[A.numCols];
+            int[] found = new int[A.numCols];
             TriangularSolver_DSCC.eliminationTree(A,true,found,null);
 
             for (int i = 0; i < A.numCols; i++) {
@@ -706,11 +707,12 @@ public class TestTriangularSolver_DSCC {
             DMatrixSparseCSC tall = CommonOps_DSCC.concatRows(A,bottom,null);
 
             DMatrixSparseCSC ATA = new DMatrixSparseCSC(N,N,0);
-            CommonOps_DSCC.multTransA(tall,tall,ATA,null,null);
+            DMatrixSparseCSC tall_t = CommonOps_DSCC.transpose(tall,null,null);
+            CommonOps_DSCC.mult(tall_t,tall,ATA,null,null);
 
-            int expected[] = new int[A.numCols];
+            int[] expected = new int[A.numCols];
             TriangularSolver_DSCC.eliminationTree(ATA,false,expected,null);
-            int found[] = new int[A.numCols];
+            int[] found = new int[A.numCols];
             TriangularSolver_DSCC.eliminationTree(tall,true,found,null);
 
             for (int i = 0; i < A.numCols; i++) {
@@ -724,11 +726,11 @@ public class TestTriangularSolver_DSCC {
      */
     @Test
     public void postorder_case0() {
-        int parent[] =   new int[]{5,2,7,5,7,6,8,9,9,10,-1};
+        int[] parent =   new int[]{5,2,7,5,7,6,8,9,9,10,-1};
 
         int N = 11;
 
-        int found[] = new int[N];
+        int[] found = new int[N];
 
         TriangularSolver_DSCC.postorder(parent,N,found,null);
 
@@ -738,13 +740,13 @@ public class TestTriangularSolver_DSCC {
     /**
      * Uses the definition to see if a list is post-ordered
      */
-    private void assertPostorder( int parent[], int order[], int N ) {
+    private void assertPostorder(int[] parent, int[] order, int N ) {
 
-        int mod[] = new int[N];
-        int sanity[] = new int[N];
+        int[] mod = new int[N];
+        int[] sanity = new int[N];
 
         // reverse[ original index ] = postorder index
-        int reverse[] = new int[N];
+        int[] reverse = new int[N];
 
         // create a reverse lookup table
         for (int i = 0; i < N; i++) {
@@ -782,10 +784,10 @@ public class TestTriangularSolver_DSCC {
      */
     @Test
     public void postorder_case1() {
-        int parent[] =   new int[]{-1,-1,-1,-1,-1};
+        int[] parent =   new int[]{-1,-1,-1,-1,-1};
         int N = 5;
 
-        int found[] = new int[N];
+        int[] found = new int[N];
 
         TriangularSolver_DSCC.postorder(parent,N,found,null);
 
@@ -797,11 +799,11 @@ public class TestTriangularSolver_DSCC {
      */
     @Test
     public void postorder_case2() {
-        int parent[] =   new int[]{5,2,7,5,7,6,8,-1,-1};
+        int[] parent =   new int[]{5,2,7,5,7,6,8,-1,-1};
 
         int N = 9;
 
-        int found[] = new int[N];
+        int[] found = new int[N];
 
         TriangularSolver_DSCC.postorder(parent,N,found,null);
 
@@ -822,11 +824,13 @@ public class TestTriangularSolver_DSCC {
                         "0 0 0 0 0 1 1 " +
                         "0 0 0 0 0 0 1 ",7);
 
-        int parent[] = new int[]{2,3,3,4,5,6,-1};
+        int[] parent = new int[]{2,3,3,4,5,6,-1};
 
-        int top, s[] = new int[7], w[] = new int[7];
+        int top;
+        int[] s = new int[7];
+        int[] w = new int[7];
 
-        int expected[];
+        int[] expected;
 
         // check each row one at a time
         top = TriangularSolver_DSCC.searchNzRowsElim(A,0,parent,s,w);
@@ -864,8 +868,8 @@ public class TestTriangularSolver_DSCC {
     /**
      * Makes sure the same elements are contained in the two list but order doesn't matter
      */
-    private static void assertSetEquals( int expected[] , int found[], int start , int end ) {
-        boolean matched[] = new boolean[end];
+    private static void assertSetEquals(int[] expected, int[] found, int start , int end ) {
+        boolean[] matched = new boolean[end];
         for (int i = start; i < end; i++) {
             if( matched[i] )
                 fail("matched twice");
