@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2017, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2009-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -18,7 +18,7 @@
 
 package org.ejml.data;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 
 /**
@@ -30,6 +30,7 @@ public class TestDenseD2Matrix64F {
     public void testGeneric() {
         GenericTestsDMatrix g;
         g = new GenericTestsDMatrix() {
+            @Override
             protected DMatrix createMatrix(int numRows, int numCols) {
                 return new DenseD2Matrix64F(numRows,numCols);
             }
