@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2018, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of Efficient Java Matrix Library (EJML).
  *
@@ -26,14 +26,14 @@ import org.ejml.data.ZMatrixRMaj;
 import org.ejml.dense.row.mult.MatrixMatrixMult_ZDRM;
 import org.ejml.dense.row.mult.TestMatrixMatrixMult_ZDRM;
 import org.ejml.ops.ComplexMath_F64;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.Random;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 /**
  * @author Peter Abeles
@@ -43,74 +43,74 @@ public class TestCommonOps_ZDRM {
     Random rand = new Random(234);
 
     @Test
-    public void identity_one() {
+    void identity_one() {
         ZMatrixRMaj I = CommonOps_ZDRM.identity(4);
-        assertEquals(4,I.numRows);
-        assertEquals(4,I.numCols);
+        assertEquals(4, I.numRows);
+        assertEquals(4, I.numCols);
 
         assertTrue(MatrixFeatures_ZDRM.isIdentity(I, UtilEjml.TEST_F64));
     }
 
     @Test
-    public void identity_two() {
-        ZMatrixRMaj I = CommonOps_ZDRM.identity(4,5);
-        assertEquals(4,I.numRows);
-        assertEquals(5,I.numCols);
+    void identity_two() {
+        ZMatrixRMaj I = CommonOps_ZDRM.identity(4, 5);
+        assertEquals(4, I.numRows);
+        assertEquals(5, I.numCols);
 
-        assertTrue(MatrixFeatures_ZDRM.isIdentity(I,UtilEjml.TEST_F64));
+        assertTrue(MatrixFeatures_ZDRM.isIdentity(I, UtilEjml.TEST_F64));
 
-        I = CommonOps_ZDRM.identity(5,4);
-        assertEquals(5,I.numRows);
-        assertEquals(4,I.numCols);
+        I = CommonOps_ZDRM.identity(5, 4);
+        assertEquals(5, I.numRows);
+        assertEquals(4, I.numCols);
 
-        assertTrue(MatrixFeatures_ZDRM.isIdentity(I,UtilEjml.TEST_F64));
+        assertTrue(MatrixFeatures_ZDRM.isIdentity(I, UtilEjml.TEST_F64));
     }
 
     @Test
-    public void diag() {
-        ZMatrixRMaj m = CommonOps_ZDRM.diag(1,2,3,4,5,6);
+    void diag() {
+        ZMatrixRMaj m = CommonOps_ZDRM.diag(1, 2, 3, 4, 5, 6);
 
-        assertEquals(3,m.numRows);
-        assertEquals(3,m.numCols);
+        assertEquals(3, m.numRows);
+        assertEquals(3, m.numCols);
 
         Complex_F64 a = new Complex_F64();
 
         for (int i = 0; i < 3; i++) {
             for (int j = 0; j < 3; j++) {
-                m.get(i,j,a);
+                m.get(i, j, a);
 
-                if( i == j ) {
-                    assertEquals(2*i+1,a.real,UtilEjml.TEST_F64);
-                    assertEquals(2*i+2,a.imaginary,UtilEjml.TEST_F64);
+                if (i == j) {
+                    assertEquals(2*i + 1, a.real, UtilEjml.TEST_F64);
+                    assertEquals(2*i + 2, a.imaginary, UtilEjml.TEST_F64);
                 } else {
-                    assertEquals(0,a.real,UtilEjml.TEST_F64);
-                    assertEquals(0,a.imaginary,UtilEjml.TEST_F64);
+                    assertEquals(0, a.real, UtilEjml.TEST_F64);
+                    assertEquals(0, a.imaginary, UtilEjml.TEST_F64);
                 }
             }
         }
     }
 
     @Test
-    public void extractDiag() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(3,4, 0, 1, rand);
+    void extractDiag() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(3, 4, 0, 1, rand);
 
-        for( int i = 0; i < 3; i++ ) {
-            a.set(i,i,i+1,0.1);
+        for (int i = 0; i < 3; i++) {
+            a.set(i, i, i + 1, 0.1);
         }
 
-        ZMatrixRMaj v = new ZMatrixRMaj(3,1);
+        ZMatrixRMaj v = new ZMatrixRMaj(3, 1);
         CommonOps_ZDRM.extractDiag(a, v);
 
-        for( int i = 0; i < 3; i++ ) {
-            assertEquals( i+1 , v.getReal(i) , UtilEjml.TEST_F64 );
-            assertEquals( 0.1 , v.getImag(i) , UtilEjml.TEST_F64 );
+        for (int i = 0; i < 3; i++) {
+            assertEquals(i + 1, v.getReal(i), UtilEjml.TEST_F64);
+            assertEquals(0.1, v.getImag(i), UtilEjml.TEST_F64);
         }
     }
 
     @Test
-    public void convert() {
-        DMatrixRMaj input = RandomMatrices_DDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj output = new ZMatrixRMaj(5,7);
+    void convert() {
+        DMatrixRMaj input = RandomMatrices_DDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj output = new ZMatrixRMaj(5, 7);
 
         Complex_F64 a = new Complex_F64();
 
@@ -118,18 +118,18 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < input.numRows; i++) {
             for (int j = 0; j < input.numCols; j++) {
-                output.get(i,j,a);
+                output.get(i, j, a);
 
-                assertEquals(input.get(i,j),a.getReal(),UtilEjml.TEST_F64);
-                assertEquals(0,a.getImaginary(),UtilEjml.TEST_F64);
+                assertEquals(input.get(i, j), a.getReal(), UtilEjml.TEST_F64);
+                assertEquals(0, a.getImaginary(), UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void stripReal() {
-        ZMatrixRMaj input = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        DMatrixRMaj output = new DMatrixRMaj(5,7);
+    void stripReal() {
+        ZMatrixRMaj input = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        DMatrixRMaj output = new DMatrixRMaj(5, 7);
 
         Complex_F64 a = new Complex_F64();
 
@@ -137,17 +137,17 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < input.numRows; i++) {
             for (int j = 0; j < input.numCols; j++) {
-                input.get(i,j,a);
+                input.get(i, j, a);
 
-                assertEquals(a.getReal(),output.get(i,j),UtilEjml.TEST_F64);
+                assertEquals(a.getReal(), output.get(i, j), UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void stripImaginary() {
-        ZMatrixRMaj input = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        DMatrixRMaj output = new DMatrixRMaj(5,7);
+    void stripImaginary() {
+        ZMatrixRMaj input = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        DMatrixRMaj output = new DMatrixRMaj(5, 7);
 
         Complex_F64 a = new Complex_F64();
 
@@ -155,17 +155,17 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < input.numRows; i++) {
             for (int j = 0; j < input.numCols; j++) {
-                input.get(i,j,a);
+                input.get(i, j, a);
 
-                assertEquals(a.getImaginary(),output.get(i,j),UtilEjml.TEST_F64);
+                assertEquals(a.getImaginary(), output.get(i, j), UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void magnitude() {
-        ZMatrixRMaj input = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        DMatrixRMaj output = new DMatrixRMaj(5,7);
+    void magnitude() {
+        ZMatrixRMaj input = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        DMatrixRMaj output = new DMatrixRMaj(5, 7);
 
         Complex_F64 a = new Complex_F64();
 
@@ -173,49 +173,49 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < input.numRows; i++) {
             for (int j = 0; j < input.numCols; j++) {
-                input.get(i,j,a);
+                input.get(i, j, a);
 
-                assertEquals(a.getMagnitude(),output.get(i,j),UtilEjml.TEST_F64);
+                assertEquals(a.getMagnitude(), output.get(i, j), UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void conjugate() {
-        ZMatrixRMaj matrix = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj found = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void conjugate() {
+        ZMatrixRMaj matrix = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj found = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
-        CommonOps_ZDRM.conjugate(matrix,found);
+        CommonOps_ZDRM.conjugate(matrix, found);
 
         for (int i = 0; i < matrix.getDataLength(); i += 2) {
             double real = matrix.data[i];
-            double img = matrix.data[i+1];
+            double img = matrix.data[i + 1];
 
-            assertEquals(real, found.data[i],UtilEjml.TEST_F64);
-            assertEquals(img, -found.data[i+1],UtilEjml.TEST_F64);
+            assertEquals(real, found.data[i], UtilEjml.TEST_F64);
+            assertEquals(img, -found.data[i + 1], UtilEjml.TEST_F64);
         }
     }
 
     @Test
-    public void fill() {
-        ZMatrixRMaj matrix = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void fill() {
+        ZMatrixRMaj matrix = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
-        CommonOps_ZDRM.fill(matrix,2,-1);
+        CommonOps_ZDRM.fill(matrix, 2, -1);
 
         for (int i = 0; i < matrix.getDataLength(); i += 2) {
             double real = matrix.data[i];
-            double img = matrix.data[i+1];
+            double img = matrix.data[i + 1];
 
-            assertEquals(2,real,UtilEjml.TEST_F64);
-            assertEquals(-1,img,UtilEjml.TEST_F64);
+            assertEquals(2, real, UtilEjml.TEST_F64);
+            assertEquals(-1, img, UtilEjml.TEST_F64);
         }
     }
 
     @Test
-    public void add() {
-        ZMatrixRMaj matrixA = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj matrixB = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void add() {
+        ZMatrixRMaj matrixA = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj matrixB = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
         Complex_F64 a = new Complex_F64();
         Complex_F64 b = new Complex_F64();
@@ -226,23 +226,23 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < matrixA.numRows; i++) {
             for (int j = 0; j < matrixA.numCols; j++) {
-                matrixA.get(i,j,a);
-                matrixB.get(i,j,b);
-                out.get(i,j,found);
+                matrixA.get(i, j, a);
+                matrixB.get(i, j, b);
+                out.get(i, j, found);
 
                 ComplexMath_F64.plus(a, b, expected);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void subtract() {
-        ZMatrixRMaj matrixA = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj matrixB = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void subtract() {
+        ZMatrixRMaj matrixA = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj matrixB = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
         Complex_F64 a = new Complex_F64();
         Complex_F64 b = new Complex_F64();
@@ -253,23 +253,23 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < matrixA.numRows; i++) {
             for (int j = 0; j < matrixA.numCols; j++) {
-                matrixA.get(i,j,a);
-                matrixB.get(i,j,b);
-                out.get(i,j,found);
+                matrixA.get(i, j, a);
+                matrixB.get(i, j, b);
+                out.get(i, j, found);
 
                 ComplexMath_F64.minus(a, b, expected);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void scale() {
-        Complex_F64 scale = new Complex_F64(2.5,0.4);
+    void scale() {
+        Complex_F64 scale = new Complex_F64(2.5, 0.4);
 
-        ZMatrixRMaj mat = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+        ZMatrixRMaj mat = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
         ZMatrixRMaj orig = mat.copy();
 
         CommonOps_ZDRM.scale(scale.real, scale.imaginary, mat);
@@ -279,11 +279,11 @@ public class TestCommonOps_ZDRM {
         for (int i = 0; i < mat.numRows; i++) {
             for (int j = 0; j < mat.numCols; j++) {
 //                System.out.println("i "+i+" j "+j);
-                orig.get(i,j,value);
+                orig.get(i, j, value);
 
-                ComplexMath_F64.multiply(scale,value,expected);
-                assertEquals(expected.real, mat.getReal(i,j), UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary, mat.getImag(i,j), UtilEjml.TEST_F64);
+                ComplexMath_F64.multiply(scale, value, expected);
+                assertEquals(expected.real, mat.getReal(i, j), UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, mat.getImag(i, j), UtilEjml.TEST_F64);
             }
         }
     }
@@ -292,14 +292,14 @@ public class TestCommonOps_ZDRM {
      * Make sure the multiplication methods here have the same behavior as the ones in MatrixMatrixMult.
      */
     @Test
-    public void checkAllMatrixMult() {
+    void checkAllMatrixMult() {
         int numChecked = 0;
         Method methods[] = CommonOps_ZDRM.class.getMethods();
 
         for (Method method : methods) {
             String name = method.getName();
 
-            if( !name.startsWith("mult"))
+            if (!name.startsWith("mult"))
                 continue;
 
             //            System.out.println(name);
@@ -310,7 +310,7 @@ public class TestCommonOps_ZDRM {
             boolean hasAlpha = double.class == params[0];
             boolean transA = name.contains("TransA");
             boolean transB = name.contains("TransB");
-            if( name.contains("TransAB") )
+            if (name.contains("TransAB"))
                 transA = transB = true;
 
             try {
@@ -323,14 +323,14 @@ public class TestCommonOps_ZDRM {
             numChecked++;
         }
 
-        assertEquals(16,numChecked);
+        assertEquals(16, numChecked);
     }
 
     @Test
-    public void multiply() {
+    void multiply() {
         for (int i = 1; i < 10; i++) {
             for (int j = 1; j < 10; j++) {
-                ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(i,j,-1,1,rand);
+                ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(i, j, -1, 1, rand);
                 for (int k = 1; k < 10; k++) {
                     ZMatrixRMaj B = RandomMatrices_ZDRM.rectangle(j, k, -1, 1, rand);
                     ZMatrixRMaj found = RandomMatrices_ZDRM.rectangle(i, k, -1, 1, rand);
@@ -338,16 +338,16 @@ public class TestCommonOps_ZDRM {
 
                     MatrixMatrixMult_ZDRM.mult_reorder(A, B, found);
 
-                    assertTrue(i+" "+j+" "+k, MatrixFeatures_ZDRM.isEquals(expected, found, UtilEjml.TEST_F64));
+                    assertTrue(MatrixFeatures_ZDRM.isEquals(expected, found, UtilEjml.TEST_F64), i + " " + j + " " + k);
                 }
             }
         }
     }
 
     @Test
-    public void transpose_one() {
+    void transpose_one() {
 
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4,4,-1,1,rand);
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4, 4, -1, 1, rand);
         ZMatrixRMaj b = a.copy();
 
         CommonOps_ZDRM.transpose(b);
@@ -357,19 +357,19 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < 4; i++) {
             for (int j = 0; j < 4; j++) {
-                a.get(i,j,expected);
-                b.get(j,i,found);
+                a.get(i, j, expected);
+                b.get(j, i, found);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void transposeConjugate_one() {
+    void transposeConjugate_one() {
 
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4,4,-1,1,rand);
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4, 4, -1, 1, rand);
         ZMatrixRMaj b = a.copy();
 
         CommonOps_ZDRM.transposeConjugate(b);
@@ -379,20 +379,20 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < 4; i++) {
             for (int j = 0; j < 4; j++) {
-                a.get(i,j,expected);
-                b.get(j,i,found);
+                a.get(i, j, expected);
+                b.get(j, i, found);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(-expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(-expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void transpose_two() {
+    void transpose_two() {
 
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4,5,-1,1,rand);
-        ZMatrixRMaj b = RandomMatrices_ZDRM.rectangle(5,4,-1,1,rand);
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4, 5, -1, 1, rand);
+        ZMatrixRMaj b = RandomMatrices_ZDRM.rectangle(5, 4, -1, 1, rand);
 
         CommonOps_ZDRM.transpose(a, b);
 
@@ -401,20 +401,20 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < 4; i++) {
             for (int j = 0; j < 5; j++) {
-                a.get(i,j,expected);
-                b.get(j,i,found);
+                a.get(i, j, expected);
+                b.get(j, i, found);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void transposeConjugate_two() {
+    void transposeConjugate_two() {
 
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4,5,-1,1,rand);
-        ZMatrixRMaj b = RandomMatrices_ZDRM.rectangle(5,4,-1,1,rand);
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4, 5, -1, 1, rand);
+        ZMatrixRMaj b = RandomMatrices_ZDRM.rectangle(5, 4, -1, 1, rand);
 
         CommonOps_ZDRM.transposeConjugate(a, b);
 
@@ -423,32 +423,32 @@ public class TestCommonOps_ZDRM {
 
         for (int i = 0; i < 4; i++) {
             for (int j = 0; j < 5; j++) {
-                a.get(i,j,expected);
-                b.get(j,i,found);
+                a.get(i, j, expected);
+                b.get(j, i, found);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(-expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(-expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void invert_1() {
+    void invert_1() {
         for (int i = 1; i < 10; i++) {
-            ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(i,i,rand);
+            ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(i, i, rand);
             ZMatrixRMaj A_orig = A.copy();
 
-            ZMatrixRMaj I = RandomMatrices_ZDRM.rectangle(i,i,rand);
+            ZMatrixRMaj I = RandomMatrices_ZDRM.rectangle(i, i, rand);
 
             assertTrue(CommonOps_ZDRM.invert(A));
-            CommonOps_ZDRM.mult(A_orig,A,I);
+            CommonOps_ZDRM.mult(A_orig, A, I);
 
             assertTrue(MatrixFeatures_ZDRM.isIdentity(I, UtilEjml.TEST_F64));
         }
     }
 
     @Test
-    public void invert_2() {
+    void invert_2() {
         for (int i = 1; i < 10; i++) {
             ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(i, i, rand);
             ZMatrixRMaj A_orig = A.copy();
@@ -465,7 +465,7 @@ public class TestCommonOps_ZDRM {
     }
 
     @Test
-    public void solve() {
+    void solve() {
         // square
         for (int i = 1; i < 10; i++) {
             ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(i, i, rand);
@@ -492,9 +492,9 @@ public class TestCommonOps_ZDRM {
         for (int i = 1; i < 10; i++) {
             ZMatrixRMaj A = RandomMatrices_ZDRM.rectangle(2*i, i, rand);
             ZMatrixRMaj X = RandomMatrices_ZDRM.rectangle(i, 1, rand);
-            ZMatrixRMaj B = new ZMatrixRMaj(2*i,1);
+            ZMatrixRMaj B = new ZMatrixRMaj(2*i, 1);
 
-            CommonOps_ZDRM.mult(A,X,B);
+            CommonOps_ZDRM.mult(A, X, B);
 
             ZMatrixRMaj A_orig = A.copy();
             ZMatrixRMaj B_orig = B.copy();
@@ -510,112 +510,112 @@ public class TestCommonOps_ZDRM {
     }
 
     @Test
-    public void det() {
-        ZMatrixRMaj A = new ZMatrixRMaj(3,3,true,
-                0.854634 , 0.445620,  0.082836 , 0.212460 , 0.623783 , 0.037631,
-                0.585408 , 0.768956 , 0.771067 , 0.897763 , 0.125793 , 0.432187,
-                0.303789 , 0.044497 , 0.151182 , 0.034471 , 0.526770 , 0.570333);
+    void det() {
+        ZMatrixRMaj A = new ZMatrixRMaj(3, 3, true,
+                0.854634, 0.445620, 0.082836, 0.212460, 0.623783, 0.037631,
+                0.585408, 0.768956, 0.771067, 0.897763, 0.125793, 0.432187,
+                0.303789, 0.044497, 0.151182, 0.034471, 0.526770, 0.570333);
 
         ZMatrixRMaj A_orig = A.copy();
 
         Complex_F64 found = CommonOps_ZDRM.det(A);
         // from octave
-        Complex_F64 expected = new Complex_F64(-0.40548 , 0.54188);
+        Complex_F64 expected = new Complex_F64(-0.40548, 0.54188);
 
-        assertEquals(expected.real,found.real,1e-3);
-        assertEquals(expected.imaginary,found.imaginary,1e-3);
+        assertEquals(expected.real, found.real, 1e-3);
+        assertEquals(expected.imaginary, found.imaginary, 1e-3);
 
-        assertTrue(MatrixFeatures_ZDRM.isIdentical(A,A_orig,0));
+        assertTrue(MatrixFeatures_ZDRM.isIdentical(A, A_orig, 0));
     }
 
     @Test
-    public void elementMultiply() {
-        ZMatrixRMaj in = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void elementMultiply() {
+        ZMatrixRMaj in = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
-        Complex_F64 a = new Complex_F64(1.2,-0.3);
+        Complex_F64 a = new Complex_F64(1.2, -0.3);
         Complex_F64 b = new Complex_F64();
         Complex_F64 found = new Complex_F64();
         Complex_F64 expected = new Complex_F64();
 
-        CommonOps_ZDRM.elementMultiply(in,a.real,a.imaginary,out);
+        CommonOps_ZDRM.elementMultiply(in, a.real, a.imaginary, out);
 
         for (int i = 0; i < in.numRows; i++) {
             for (int j = 0; j < in.numCols; j++) {
-                in.get(i,j,b);
-                out.get(i,j,found);
+                in.get(i, j, b);
+                out.get(i, j, found);
 
-                ComplexMath_F64.multiply(a,b,expected);
+                ComplexMath_F64.multiply(a, b, expected);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void elementDivide_right() {
-        ZMatrixRMaj in = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void elementDivide_right() {
+        ZMatrixRMaj in = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
         Complex_F64 a = new Complex_F64();
-        Complex_F64 b = new Complex_F64(1.2,-0.3);
+        Complex_F64 b = new Complex_F64(1.2, -0.3);
         Complex_F64 found = new Complex_F64();
         Complex_F64 expected = new Complex_F64();
 
-        CommonOps_ZDRM.elementDivide(in,b.real,b.imaginary,out);
+        CommonOps_ZDRM.elementDivide(in, b.real, b.imaginary, out);
 
         for (int i = 0; i < in.numRows; i++) {
             for (int j = 0; j < in.numCols; j++) {
-                in.get(i,j,a);
-                out.get(i,j,found);
+                in.get(i, j, a);
+                out.get(i, j, found);
 
-                ComplexMath_F64.divide(a,b,expected);
+                ComplexMath_F64.divide(a, b, expected);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void elementDivide_left() {
-        ZMatrixRMaj in = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
-        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5,7,-1,1,rand);
+    void elementDivide_left() {
+        ZMatrixRMaj in = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
+        ZMatrixRMaj out = RandomMatrices_ZDRM.rectangle(5, 7, -1, 1, rand);
 
-        Complex_F64 a = new Complex_F64(1.2,-0.3);
+        Complex_F64 a = new Complex_F64(1.2, -0.3);
         Complex_F64 b = new Complex_F64();
         Complex_F64 found = new Complex_F64();
         Complex_F64 expected = new Complex_F64();
 
-        CommonOps_ZDRM.elementDivide(a.real,a.imaginary,in,out);
+        CommonOps_ZDRM.elementDivide(a.real, a.imaginary, in, out);
 
         for (int i = 0; i < in.numRows; i++) {
             for (int j = 0; j < in.numCols; j++) {
-                in.get(i,j,b);
-                out.get(i,j,found);
+                in.get(i, j, b);
+                out.get(i, j, found);
 
-                ComplexMath_F64.divide(a,b,expected);
+                ComplexMath_F64.divide(a, b, expected);
 
-                assertEquals(expected.real,found.real,UtilEjml.TEST_F64);
-                assertEquals(expected.imaginary,found.imaginary,UtilEjml.TEST_F64);
+                assertEquals(expected.real, found.real, UtilEjml.TEST_F64);
+                assertEquals(expected.imaginary, found.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void elementMinReal() {
-        ZMatrixRMaj m = new ZMatrixRMaj(3,4);
+    void elementMinReal() {
+        ZMatrixRMaj m = new ZMatrixRMaj(3, 4);
         for (int i = 0; i < m.data.length; i++) {
             m.data[i] = -6 + i;
         }
 
-        assertEquals(-6, CommonOps_ZDRM.elementMinReal(m),UtilEjml.TEST_F64);
+        assertEquals(-6, CommonOps_ZDRM.elementMinReal(m), UtilEjml.TEST_F64);
     }
 
     @Test
-    public void elementMinImaginary() {
-        ZMatrixRMaj m = new ZMatrixRMaj(3,4);
+    void elementMinImaginary() {
+        ZMatrixRMaj m = new ZMatrixRMaj(3, 4);
         for (int i = 0; i < m.data.length; i++) {
             m.data[i] = -6 + i;
         }
@@ -624,105 +624,105 @@ public class TestCommonOps_ZDRM {
     }
 
     @Test
-    public void elementMaxReal() {
-        ZMatrixRMaj m = new ZMatrixRMaj(3,4);
+    void elementMaxReal() {
+        ZMatrixRMaj m = new ZMatrixRMaj(3, 4);
         for (int i = 0; i < m.data.length; i++) {
             m.data[i] = -6 + i;
         }
 
-        assertEquals(-6 + 11 * 2, CommonOps_ZDRM.elementMaxReal(m), UtilEjml.TEST_F64);
+        assertEquals(-6 + 11*2, CommonOps_ZDRM.elementMaxReal(m), UtilEjml.TEST_F64);
     }
 
     @Test
-    public void elementMaxImaginary() {
-        ZMatrixRMaj m = new ZMatrixRMaj(3,4);
+    void elementMaxImaginary() {
+        ZMatrixRMaj m = new ZMatrixRMaj(3, 4);
         for (int i = 0; i < m.data.length; i++) {
             m.data[i] = -6 + i;
         }
 
-        assertEquals(-5 + 11 * 2, CommonOps_ZDRM.elementMaxImaginary(m), UtilEjml.TEST_F64);
+        assertEquals(-5 + 11*2, CommonOps_ZDRM.elementMaxImaginary(m), UtilEjml.TEST_F64);
     }
 
     @Test
-    public void elementMaxMagnitude2() {
-        ZMatrixRMaj m = RandomMatrices_ZDRM.rectangle(4,5,-2,2,rand);
-        DMatrixRMaj a = new DMatrixRMaj(m.numRows,m.numCols);
+    void elementMaxMagnitude2() {
+        ZMatrixRMaj m = RandomMatrices_ZDRM.rectangle(4, 5, -2, 2, rand);
+        DMatrixRMaj a = new DMatrixRMaj(m.numRows, m.numCols);
 
-        CommonOps_ZDRM.magnitude(m,a);
+        CommonOps_ZDRM.magnitude(m, a);
 
         double expected = CommonOps_DDRM.elementMaxAbs(a);
         expected *= expected;
 
         double found = CommonOps_ZDRM.elementMaxMagnitude2(m);
 
-        assertEquals(expected,found,UtilEjml.TEST_F64);
+        assertEquals(expected, found, UtilEjml.TEST_F64);
     }
 
     @Test
-    public void setIdentity() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4,5,-2,2,rand);
+    void setIdentity() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(4, 5, -2, 2, rand);
 
         CommonOps_ZDRM.setIdentity(a);
 
         Complex_F64 c = new Complex_F64();
         for (int i = 0; i < a.numRows; i++) {
             for (int j = 0; j < a.numCols; j++) {
-                a.get(i,j,c);
-                if( i == j ) {
-                    assertEquals(1,c.real,UtilEjml.TEST_F64);
-                    assertEquals(0,c.imaginary,UtilEjml.TEST_F64);
+                a.get(i, j, c);
+                if (i == j) {
+                    assertEquals(1, c.real, UtilEjml.TEST_F64);
+                    assertEquals(0, c.imaginary, UtilEjml.TEST_F64);
                 } else {
-                    assertEquals(0,c.real,UtilEjml.TEST_F64);
-                    assertEquals(0,c.imaginary,UtilEjml.TEST_F64);
+                    assertEquals(0, c.real, UtilEjml.TEST_F64);
+                    assertEquals(0, c.imaginary, UtilEjml.TEST_F64);
                 }
             }
         }
     }
 
     @Test
-    public void extract_simplified() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10,12,-2,2,rand);
-        ZMatrixRMaj b = CommonOps_ZDRM.extract(a,2,5,3,8);
+    void extract_simplified() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10, 12, -2, 2, rand);
+        ZMatrixRMaj b = CommonOps_ZDRM.extract(a, 2, 5, 3, 8);
 
         Complex_F64 ca = new Complex_F64();
         Complex_F64 cb = new Complex_F64();
 
         for (int i = 0; i < 3; i++) {
             for (int j = 0; j < 5; j++) {
-                a.get(2+i,j+3,ca);
-                b.get(  i,j  , cb);
+                a.get(2 + i, j + 3, ca);
+                b.get(i, j, cb);
 
-                assertEquals(ca.real,cb.real,UtilEjml.TEST_F64);
-                assertEquals(ca.imaginary,cb.imaginary,UtilEjml.TEST_F64);
+                assertEquals(ca.real, cb.real, UtilEjml.TEST_F64);
+                assertEquals(ca.imaginary, cb.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void extract_complex() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10,12,-2,2,rand);
-        ZMatrixRMaj b = new ZMatrixRMaj(6,7);
+    void extract_complex() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10, 12, -2, 2, rand);
+        ZMatrixRMaj b = new ZMatrixRMaj(6, 7);
 
         Complex_F64 ca = new Complex_F64();
         Complex_F64 cb = new Complex_F64();
 
-        CommonOps_ZDRM.extract(a,2,5,3,7,b,1,2);
+        CommonOps_ZDRM.extract(a, 2, 5, 3, 7, b, 1, 2);
 
         for (int i = 0; i < 3; i++) {
             for (int j = 0; j < 4; j++) {
-                a.get(2+i,j+3,ca);
+                a.get(2 + i, j + 3, ca);
                 b.get(1 + i, j + 2, cb);
 
-                assertEquals(ca.real,cb.real,UtilEjml.TEST_F64);
-                assertEquals(ca.imaginary,cb.imaginary,UtilEjml.TEST_F64);
+                assertEquals(ca.real, cb.real, UtilEjml.TEST_F64);
+                assertEquals(ca.imaginary, cb.imaginary, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void columnsToVector() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10,12,-2,2,rand);
-        ZMatrixRMaj v[] = CommonOps_ZDRM.columnsToVector(a,null);
+    void columnsToVector() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10, 12, -2, 2, rand);
+        ZMatrixRMaj v[] = CommonOps_ZDRM.columnsToVector(a, null);
 
         Complex_F64 ca = new Complex_F64();
         Complex_F64 cc = new Complex_F64();
@@ -730,35 +730,35 @@ public class TestCommonOps_ZDRM {
         for (int i = 0; i < a.numCols; i++) {
             ZMatrixRMaj c = v[i];
 
-            assertEquals(c.numRows,a.numRows);
-            assertEquals(1,c.numCols);
+            assertEquals(c.numRows, a.numRows);
+            assertEquals(1, c.numCols);
 
             for (int j = 0; j < a.numRows; j++) {
-                a.get(j,i,ca);
-                c.get(j,0,cc);
+                a.get(j, i, ca);
+                c.get(j, 0, cc);
 
-                EjmlUnitTests.assertEquals(ca,cc,UtilEjml.TEST_F64);
+                EjmlUnitTests.assertEquals(ca, cc, UtilEjml.TEST_F64);
             }
         }
     }
 
     @Test
-    public void elementMaxAbs() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10,12,-2,2,rand);
-        a.set(5,6,10,12);
+    void elementMaxAbs() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10, 12, -2, 2, rand);
+        a.set(5, 6, 10, 12);
 
         double expected = Math.sqrt(10*10 + 12*12);
         double found = CommonOps_ZDRM.elementMaxAbs(a);
-        assertEquals(expected,found,UtilEjml.TEST_F64);
+        assertEquals(expected, found, UtilEjml.TEST_F64);
     }
 
     @Test
-    public void elementMinAbs() {
-        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10,12,-8,-2,rand);
-        a.set(5,6,1,2);
+    void elementMinAbs() {
+        ZMatrixRMaj a = RandomMatrices_ZDRM.rectangle(10, 12, -8, -2, rand);
+        a.set(5, 6, 1, 2);
 
         double expected = Math.sqrt(1 + 2*2);
         double found = CommonOps_ZDRM.elementMinAbs(a);
-        assertEquals(expected,found,UtilEjml.TEST_F64);
+        assertEquals(expected, found, UtilEjml.TEST_F64);
     }
 }
\ No newline at end of file
